﻿Fluke Calibration                                           MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub Tek MSO Get Digital Threshold Values VISA /O_CAL
DATE:                  2019-03-26 09:55:10
AUTHOR:                Fluke
REVISION:              $Revision: 27190 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       2
NUMBER OF LINES:       423
CONFIGURATION:         Fluke Ocal
=============================================================================
#
#  Procedure Author:
#        DAC, CAD, GMO
#
#  Models Covered:
#        MSO2000, MSO2000B Series
#        MSO3000 Series
#        MDO3000 Series
#        MSO4000, MSO4000B Series
#        MDO4000, MDO4000B Series
#        MSO5000 Series
#
#  Compatibility:
#        MET/CAL 8.0 or later
#
#  Source:
#        MSO2000B and DPO2000B Series Oscilloscopes
#        Specification and Performance Verification Technical Reference
#        PN 077-0735-00
#
#  Additional Equipment Required:
#        Digital Test Probe
#          MSO2000B Series
#        Digital Calibration Fixture (PN 174-4535-00)
#          MSO4000 Series
#        TCFA074 Digital Calibration Fixture (PN 067-2121-00)
#          MSO4000B Series
#          MDO4000 Series
#          MSO5000 Series
#
#  This procedure is intended for use with MET/CAL® calibration software;
#  the terms and conditions set forth in your MET/CAL license apply to this
#  procedure.
#
#  Due to Fluke's policy of continuously updating our products, this procedure
#  may contain minor differences in methods used and/or specifications to
#  those found in the manual or other documentation. While every effort has
#  been made to ensure that this procedure is accurate, Fluke cannot be held
#  responsible for the consequences of error or omissions found within this
#  procedure.
#
#  The copyright in this procedure is owned by Fluke Corporation.
#
#  Memory Register Usage:
#
#    M[100] - M[115]:  Channel state (0 or 1)
#    M[120] - M[135]:  Average transition voltage
#    M[140] - M[155]:  Average transition voltage accuracy
#    M[160] - M[175]:  Average transition voltage found (0 or 1)
#
#    @iState: Index offset to access channel state in M registers.
#    @iVolt:  Index offset to access voltage in M registers.
#    @iAcc:   Index offset to access voltage accuracy in M registers.
#    @iFound: Index offset to access voltage found in M registers.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

  1.001  HEAD         -2 Threshold: [V @Threshold] V
  1.002  CALL         Sub Tek MDO/MSO/DPO Get Series
  1.003  MATH         MSO2  = ZCMP(@Series, "MSO2000")
  1.004  MATH         MSO2B = ZCMP(@Series, "MSO2000B")
  1.005  MATH         MSO3  = ZCMP(@Series, "MSO3000")
  1.006  MATH         MSO4  = ZCMP(@Series, "MSO4000")
  1.007  MATH         MSO4B = ZCMP(@Series, "MSO4000B")
  1.008  MATH         MSO5  = ZCMP(@Series, "MSO5000")
  1.009  MATH         MDO3  = ZCMP(@Series, "MDO3000")
  1.010  MATH         MDO4  = ZCMP(@Series, "MDO4000")
  1.011  MATH         MDO4B = ZCMP(@Series, "MDO4000B")

  1.012  TARGET

  1.013  DO
  1.014  VISA         *CLS;*RST
  1.015  CALL         Sub Tek MDO/MSO/DPO Wait for OPC VISA
  1.016  JMPL         END                          @Abort
# Setting @Chan to 0 so that the following sub procedures turns off all time domain channels.
  1.017  MATH         @Chan = 0
  1.018  CALL         Sub Tek MDO/MSO/DPO Select Channel VISA
  1.019  JMPL         END                          @Abort

  1.020  IF           @ShowConnection
  1.021  HEAD         -2 Threshold: [V @Threshold] V

# Define the names for the calibrator output channels.
# Use contents of @CalOutp, if available.
  1.022  IF           ISVAR("@CalOutp")
  1.023  MATH         CalOutp = @CalOutp
  1.024  ELSE

  1.025  IF           FINDI(@CalDev, "58", 0)
  1.026  MATH         CalOutp = "CHAN 1 OUTPUT"
  1.027  ELSE
  1.028  MATH         CalOutp = "SCOPE OUT"
  1.029  ENDIF

  1.030  ENDIF        ; ISVAR("@CalOutp")

  1.031  IF           MSO2 || MSO2B || MSO3 || MDO3
  1.032  DISP         Disconnect all clip leads from the P6316 Test Probe.
  1.032  DISP
  1.032  DISP         Connect P6316 Test Probe to BNC to 0.1 in pin adapter.
  1.032  DISP         BNC to 0.1 in pin adapter (Tek P/N 679-6240-00)
  1.032  DISP         Be sure to connect corresponding signal pins and
  1.032  DISP         ground pins on the probe to the adapter.
  1.032  DISP
  1.032  DISP         Connect the P6316 Test Probe to DUT.
  1.032  DISP
  1.033  DISP         Connect the [V CalOutp] to the pin adapter.

  1.034  ELSEIF       MSO4

  1.035  DISP         Disconnect all clip leads from the P6516 Test Probe.
  1.035  DISP
  1.035  DISP         Connect P6516 Test Probe to BNC to 0.1 in pin adapter.
  1.035  DISP         BNC to 0.1 in pin adapter (Tek P/N 679-6240-00)
  1.035  DISP         Be sure to connect corresponding signal pins and
  1.035  DISP         ground pins on the probe to the adapter.
  1.035  DISP
  1.035  DISP         Connect the P6516 Test Probe to DUT.
  1.035  DISP
  1.036  DISP         Connect the [V CalOutp] to the pin adapter.

  1.037  ELSEIF       MDO4 || MDO4B || MSO4B || MSO5

  1.038  DO
  1.039  MEMI         Select connection method.
  1.039  MEMI
  1.039  MEMI         1. P6616 Test Probe and BNC to 0.1 in pin adapter, or
  1.039  MEMI
  1.039  MEMI         2. Calibration Adapter (PN 067-2121-00).
  1.040  UNTIL        (MEM == 1) || (MEM == 2)

  1.041  IF           MEM == 1
  1.042  DISP         Disconnect all clip leads from the P6616 Test Probe.
  1.042  DISP
  1.042  DISP         Connect P6616 Test Probe to BNC to 0.1 in pin adapter.
  1.042  DISP         BNC to 0.1 in pin adapter (Tek P/N 679-6240-00)
  1.042  DISP         Be sure to connect corresponding signal pins and
  1.042  DISP         ground pins on the probe to the adapter.
  1.042  DISP
  1.042  DISP         Connect the P6616 Test Probe to DUT.
  1.042  DISP
  1.043  DISP         Connect the [V CalOutp] to the pin adapter.
  1.044  ELSE
  1.045  DISP         Connect Calibration Adapter P/N 067-2121-00 to DUT.
  1.045  DISP
  1.045  DISP         Connect the [V CalOutp] to Calibration Adapter.
  1.046  ENDIF

  1.047  ELSE
  1.048  DISP         [V @Series] Series not supported!
  1.049  MATH         @Abort = 1
  1.050  ENDIF        ; MSO2 || MSO3 || MDO3

  1.051  MATH         @ShowConnection = 0
  1.052  ENDIF        ; @ShowConnection

  1.053  MATH         LeadingDigit = SUB(@ModelNum, 4, 1)

  1.054  MATH         L[1] = ZCMP(LeadingDigit, "2")
  1.055  MATH         L[1] = ZCMP(LeadingDigit, "3") || L[1]
  1.056  MATH         L[1] = ZCMP(LeadingDigit, "4") || L[1]

  1.057  IF           L[1]

  1.058  IF           ZCMP(LeadingDigit, "2")
  1.059  MATH         D15D0_OnOff = 2; Thresholds = 3
  1.060  ELSEIF       ZCMP(LeadingDigit, "3") || ZCMP(LeadingDigit, "4")
  1.061  MATH         D15D0_OnOff = 1; Thresholds = 2
  1.062  ENDIF

# Press Front Panel "D15-D0" (blue) button.
  1.063  VISA         FPA:PRESS D15D0
  1.064  CALL         Sub Tek MDO/MSO/DPO Wait for OPC VISA

# Press Bottom Menu D15-D0 On/Off Softkey
  1.065  IF           NOT(@Abort)
  1.066  VISA         FPA:PRESS BMENU[V D15D0_OnOff]
  1.067  CALL         Sub Tek MDO/MSO/DPO Wait for OPC VISA
  1.068  ENDIF

# Press Right Menu Turn On D7-D0 Softkey
  1.069  IF           NOT(@Abort)
  1.070  VISA         FPA:PRESS RMENU3
  1.071  CALL         Sub Tek MDO/MSO/DPO Wait for OPC VISA
  1.072  MATH         Source = "DIG"
  1.073  ENDIF

# Press Right Menu Turn On D15-D8 Softkey
  1.074  IF           NOT(@Abort)
  1.075  VISA         FPA:PRESS RMENU4
  1.076  CALL         Sub Tek MDO/MSO/DPO Wait for OPC VISA
  1.077  MATH         Source = "DIG"
  1.078  ENDIF

# Press Bottom Menu Thresholds Softkey
  1.079  IF           NOT(@Abort)
  1.080  VISA         FPA:PRESS BMENU[V Thresholds]
  1.081  CALL         Sub Tek MDO/MSO/DPO Wait for OPC VISA
  1.082  ENDIF

# MSO5000, MSO7000C
  1.083  ELSE
  1.084  MATH         List = "D0,D1,D2,D3,D4,D5,D6,D7"
  1.085  MATH         List = List & ",D8,D9,D10,D11,D12,D13,D14,D15"
  1.086  VISA         SEL:DIGT:LIST [V List]
  1.087  CALL         Sub Tek MDO/MSO/DPO Wait for OPC VISA
  1.088  MATH         Source = "DIGITALALL"
  1.089  ENDIF

  1.090  IF           NOT(@Abort)
  1.091  VISA         DAT:SOU [V Source];ENC ASCI
  1.092  CALL         Sub Tek MDO/MSO/DPO Wait for OPC VISA
  1.093  ENDIF

  1.094  IF           NOT(@Abort)
  1.095  VISA         DAT:START 1;STOP 1
  1.096  CALL         Sub Tek MDO/MSO/DPO Wait for OPC VISA
  1.097  ENDIF

# MSO2000, MSO2000B, MSO4000, MDO4000, MSO4000B
  1.098  IF           L[1]

# Call CLEARM to clear Vertical Button Labels.
  1.099  IF           NOT(@Abort)
  1.100  VISA         CLEARM
  1.101  CALL         Sub Tek MDO/MSO/DPO Wait for OPC VISA
  1.102  ENDIF

# Call CLEARM to clear Horizontal Button Labels.
  1.103  IF           NOT(@Abort)
  1.104  VISA         CLEARM
  1.105  CALL         Sub Tek MDO/MSO/DPO Wait for OPC VISA
  1.106  ENDIF

  1.107  ENDIF

  1.108  IF           NOT(@Abort)

  1.109  MATH         Ch = 0
  1.110  DO
  1.111  VISA         D[V Ch]:THRESHOLD [V @Threshold]
# Delete when debugged for MSO5000.
  1.112  CALL         Sub Tek MDO/MSO/DPO Wait for OPC VISA
  1.113  MATH         Ch = Ch + 1
  1.114  UNTIL        Ch > 15

# Set flags to assume all required states/data is achieved.
  1.115  MATH         AllLow  = 1; LowToHigh = 1
  1.116  MATH         AllHigh = 1; HighToLow = 1

  1.117  HEAD         -2 Threshold: [V @Threshold] V (Low to High)
  1.118  VISA         TRIG:A:EDGE:SOU D0;SLO RIS
  1.119  CALL         Sub Tek MDO/MSO/DPO Wait for OPC VISA

# Define Waveform Preamble necessary for certain DUT series.
  1.120  IF           FIND(@ModelNum, "MSO2", 1)
  1.121  VISA         WFMOUTPRE:ENCDG ASCI
  1.122  CALL         Sub Tek MDO/MSO/DPO Wait for OPC VISA
  1.123  VISA         WFMOUTPRE:COMPOSITION SINGULAR_YT
  1.124  CALL         Sub Tek MDO/MSO/DPO Wait for OPC VISA
  1.125  ENDIF

# Make sure all channels are low at starting voltage.
  1.126  MATH         Voltage = @LowVoltage
  1.127  O_CAL        Mode = Voltage; OutputImpedance = 50 Ohm
  1.127  O_CAL        +Voltage = [V @LowVoltage] V; Channel = [V @CalChan]
  1.128  WAIT         [D3000]
  1.129  CALL         Sub Tek MSO Read Digital Data VISA

# Abort if all channels are not initially low.
  1.130  MATH         Ch = 0
  1.131  MATH         AllLow = NOT(MGET(Ch + @iState))
  1.132  MATH         Ch = 1

  1.133  DO
  1.134  MATH         AllLow = AllLow || NOT(MGET(Ch + @iState))
  1.135  MATH         Ch = Ch + 1
  1.136  UNTIL        Ch > 15

  1.137  ENDIF        ; NOT(@Abort)

  1.138  IF           AllLow && NOT(@Abort)
# Initialize "Transition Found" flags to false.
  1.139  MATH         Ch = 0

  1.140  DO
  1.141  MATH         MSET((Ch + @iFound), 0)
  1.142  MATH         Ch = Ch + 1
  1.143  UNTIL        Ch > 15

# Get low to high transition value.
  1.144  DO
  1.145  O_CAL        Mode = Voltage; OutputImpedance = 50 Ohm
  1.145  O_CAL        +Voltage = [V Voltage] V; Channel = [V @CalChan]
  1.146  WAIT         [D3000]
  1.147  CALL         Sub Tek MSO Read Digital Data VISA
  1.148  MATH         Ch = 0

  1.149  DO

# Save transition voltage and reference accuracy.
  1.150  IF           NOT(MGET(Ch + @iFound)) && MGET(Ch + @iState)
  1.151  MATH         MSET((Ch + @iVolt), Voltage)
  1.152  MATH         MSET((Ch + @iAcc), REFACC())
  1.153  MATH         MSET((Ch + @iFound), 1)
  1.154  ENDIF

  1.155  MATH         Ch = Ch + 1
  1.156  UNTIL        Ch > 15

  1.157  MATH         Voltage = Voltage + 10E-3
  1.158  UNTIL        @FoundVoltages || (Voltage > @HighVoltage)

  1.159  MATH         LowToHigh = @FoundVoltages
  1.160  ENDIF        ; AllLow && NOT(@Abort)

  1.161  IF           LowToHigh && NOT(@Abort)
  1.162  HEAD         -2 Threshold: [V @Threshold] V (High to Low)
  1.163  MATH         Conf = CONF(@CalDev)
  1.164  TARGET
  1.165  VISA         TRIG:A:EDGE:SOU D0;SLO FALL
  1.166  MATH         Voltage = @HighVoltage
  1.167  O_CAL        Mode = Voltage; OutputImpedance = 50 Ohm
  1.167  O_CAL        +Voltage = [V @HighVoltage] V; Channel = [V @CalChan]
  1.168  WAIT         [D3000]
  1.169  CALL         Sub Tek MSO Read Digital Data VISA

# Abort if all channels are not initially high.
  1.170  MATH         Ch = 0
  1.171  MATH         AllHigh = MGET(Ch + @iState)
  1.172  MATH         Ch = 1

  1.173  DO
  1.174  MATH         AllHigh = AllHigh && MGET(Ch + @iState)
  1.175  MATH         Ch = Ch + 1
  1.176  UNTIL        Ch > 15

  1.177  ENDIF        ; LowToHigh && NOT(@Abort)

  1.178  IF           AllHigh && NOT(@Abort)
# Initialize "Transition Found" flags to false.
  1.179  MATH         Ch = 0

  1.180  DO
  1.181  MATH         MSET((Ch + @iFound), 0)
  1.182  MATH         Ch = Ch + 1
  1.183  UNTIL        Ch > 15

# Get high to low transition value.
  1.184  DO
  1.185  O_CAL        Mode = Voltage; OutputImpedance = 50 Ohm
  1.185  O_CAL        +Voltage = [V Voltage] V; Channel = [V @CalChan]
  1.186  WAIT         [D3000]
  1.187  CALL         Sub Tek MSO Read Digital Data VISA
  1.188  MATH         Ch = 0

  1.189  DO

# Save average transition voltage and reference accuracy.
  1.190  IF           NOT(MGET(Ch + @iFound)) && NOT(MGET(Ch + @iState))
  1.191  MATH         Avg = (MGET(Ch + @iVolt) + Voltage) / 2
  1.192  MATH         MSET(Ch + @iVolt, Avg)
  1.193  MATH         Acc = RSS2(MGET(Ch + @iAcc), REFACC()) / Conf * 2
  1.194  MATH         MSET((Ch + @iAcc), Acc)
  1.195  MATH         MSET((Ch + @iFound), 1)
  1.196  ENDIF

  1.197  MATH         Ch = Ch + 1
  1.198  UNTIL        Ch > 15

  1.199  MATH         Voltage = Voltage - 10E-3
  1.200  UNTIL        @FoundVoltages || (Voltage < @LowVoltage)

  1.201  MATH         HighToLow = @FoundVoltages
  1.202  ENDIF        ; AllHigh && NOT(@Abort)

  1.203  IF           AllLow && LowToHigh && AllHigh && HighToLow
  1.204  MATH         @GotData = 1; Done = 1;
  1.205  ELSE
  1.206  MATH         @GotData = 0;

  1.207  IF           NOT(AllLow)
  1.208  MATH         Msg = "All channels are not initially low."
  1.209  ELSEIF       NOT(LowToHigh)
  1.210  MATH         Msg = "All channels did not transition to high."
  1.211  ELSEIF       NOT(AllHigh)
  1.212  MATH         Msg = "All channels are not initially high."
  1.213  ELSEIF       NOT(HighToLow)
  1.214  MATH         Msg = "All channels did not transition to low."
  1.215  ENDIF

  1.216  OPBR         -z [V Msg]
  1.216  OPBR
  1.216  OPBR         Do you wish to try again?
  1.217  MATH         Done = NOT(MEM1)

  1.218  IF           Done
# Force a "FAIL" condition, since data could not be obtained.
  1.219  EVAL   -e 0 : [V Msg]
  2.001  ELSE
  2.002  MATH         @ShowConnection = 1
  2.003  ENDIF

  2.004  ENDIF

  2.005  UNTIL        Done || @Abort

  2.006  LABEL        END
  2.007  HEAD         -2
  2.008  O_CAL        Standby
  2.009  END
